"{ Package: 'stx:libsvn' }"

"{ NameSpace: SVN }"

Smalltalk::TestCase subclass:#TestCase
	instanceVariableNames:'workdir package manager repo wc branch'
	classVariableNames:''
	poolDictionaries:''
	category:'SVN-Tests'
!


!TestCase class methodsFor:'testing'!

isAbstract

    ^self == 
		SVN::TestCase

    "Created: / 08-04-2009 / 21:54:18 / Jan Vrany <vranyj1@fel.cvut.cz>"
! !

!TestCase methodsFor:'accessing'!

package
    ^ 'stx:goodies/libsvn_' , self class nameWithoutPrefix

    "Created: / 08-04-2009 / 21:49:53 / Jan Vrany <vranyj1@fel.cvut.cz>"
    "Modified: / 19-08-2009 / 14:21:06 / Jan Vrany <vranyj1@fel.cvut.cz>"
! !

!TestCase methodsFor:'initialization & release'!

setUp


    workdir := Filename newTemporaryDirectory.
    package := self package.
    workdir makeDirectory.
    self 
        setUpSubversion;
        setUpRepository.

    repo := manager repositoryForPackage: package.
    wc := repo workingCopy.

    "Created: / 08-04-2009 / 20:34:01 / Jan Vrany <vranyj1@fel.cvut.cz>"
    "Modified: / 19-08-2009 / 14:23:09 / Jan Vrany <vranyj1@fel.cvut.cz>"
!

setUpRepository
    |repodir|

    repodir := workdir construct:'repo'.


    (CreateRepositoryCommand new)
        repositoryPath:repodir pathName;
        execute.

    (CheckoutCommand new)
        workingCopy:wc;
        execute.

    self sources do:[:source | 
        source first = #dir ifTrue:[
            (wc path / source second) recursiveMakeDirectory
        ].
        source first = #file ifTrue:[
            |file|

            file := (wc path / source second).
            file directory recursiveMakeDirectory.
            (file writeStream)
                nextPutAll:(self perform:source third);
                close
        ]
    ].
    (AddCommand new)
        workingCopy: wc;
        paths:#( '*' );
        execute.
    (CommitCommand new)
        workingCopy: wc;
        message:'Initial commit from #setupRepository';
        execute.
    wc path
        recursiveRemove;
        makeDirectory

    "Created: / 08-04-2009 / 20:46:12 / Jan Vrany <vranyj1@fel.cvut.cz>"
    "Modified: / 19-08-2009 / 13:22:13 / Jan Vrany <vranyj1@fel.cvut.cz>"
!

setUpSubversion

    | repoUrl |
    repoUrl := 'file://' , (workdir construct:'repo') asAbsoluteFilename pathName.

    manager := SVN::RepositoryManager new.
    manager workingCopyBase:(workdir construct:'wc') pathName.
    manager configurations: 
        (Array with:
            ((SVN::RepositoryConfiguration new)
                    package: self package;
                    url: repoUrl)).
    repo := Repository package: package url: repoUrl.
    branch := Branch repository: repo path: ''.
    wc := WorkingCopy branch: branch path: manager workingCopyBase.

    "Created: / 08-04-2009 / 20:52:13 / Jan Vrany <vranyj1@fel.cvut.cz>"
    "Modified: / 19-08-2009 / 14:22:44 / Jan Vrany <vranyj1@fel.cvut.cz>"
!

tearDown

    manager := repo := wc := branch := nil.
    workdir recursiveRemove.    
    (ProjectDefinition searchForClassesWithProject: package)
        do:[:cls|cls removeFromSystem].
    (ProjectDefinition searchForExtensionsWithProject: package)
        do:[:mth|mth mclass removeSelector:mth selector].

    "Created: / 08-04-2009 / 20:34:28 / Jan Vrany <vranyj1@fel.cvut.cz>"
    "Modified: / 19-08-2009 / 14:20:40 / Jan Vrany <vranyj1@fel.cvut.cz>"
! !

!TestCase methodsFor:'sources'!

sources

    ^#()

    "Created: / 08-04-2009 / 21:31:29 / Jan Vrany <vranyj1@fel.cvut.cz>"
! !

!TestCase class methodsFor:'documentation'!

version
    ^ '$Header$'
!

version_CVS
    ^ '$Header$'
!

version_SVN
    ^'Id: SVN__TestCase.st 110 2009-08-19 13:21:10Z vranyj1 '
! !
